EnvDecoration class

Constructors

EnvDecoration({required double opacity, required EnvBannerLocation location, required Color color})

Properties

color Color
final
hashCode int
The hash code for this object.
no setterinherited
location EnvBannerLocation
final
opacity double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

decoration() Decoration
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited