ignoreMediaPadding property
Ignore the media padding.
This is used when the banner is used as a decoration for a widget.
Implementation
final bool ignoreMediaPadding;
Ignore the media padding.
This is used when the banner is used as a decoration for a widget.
final bool ignoreMediaPadding;